==> servicecatalog-model-6.6.2-sources.jar: io/fabric8/servicecatalog/api/model/AddKeyTransformFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AddKeyTransformFluentImpl<A extends AddKeyTransformFluent<A>> extends BaseFluent<A> implements AddKeyTransformFluent<A>{
  public AddKeyTransformFluentImpl() {
  }
  public AddKeyTransformFluentImpl(AddKeyTransform instance) {
    this.withJsonPathExpression(instance.getJsonPathExpression()); 
    this.withKey(instance.getKey()); 
    this.withStringValue(instance.getStringValue()); 
    this.withValue(instance.getValue()); 
  }
  private String jsonPathExpression;
  private String key;
  private String stringValue;
  private String value;
  public String getJsonPathExpression() {
    return this.jsonPathExpression;
  }
  public A withJsonPathExpression(String jsonPathExpression) {
    this.jsonPathExpression=jsonPathExpression; return (A) this;
  }
  public Boolean hasJsonPathExpression() {
    return this.jsonPathExpression != null;
  }
  public String getKey() {
    return this.key;
  }
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  public Boolean hasKey() {
    return this.key != null;
  }
  public String getStringValue() {
    return this.stringValue;
  }
  public A withStringValue(String stringValue) {
    this.stringValue=stringValue; return (A) this;
  }
  public Boolean hasStringValue() {
    return this.stringValue != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AddKeyTransformFluentImpl that = (AddKeyTransformFluentImpl) o;
    if (jsonPathExpression != null ? !jsonPathExpression.equals(that.jsonPathExpression) :that.jsonPathExpression != null) return false;
    if (key != null ? !key.equals(that.key) :that.key != null) return false;
    if (stringValue != null ? !stringValue.equals(that.stringValue) :that.stringValue != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(jsonPathExpression,  key,  stringValue,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (jsonPathExpression != null) { sb.append("jsonPathExpression:"); sb.append(jsonPathExpression + ","); }
    if (key != null) { sb.append("key:"); sb.append(key + ","); }
    if (stringValue != null) { sb.append("stringValue:"); sb.append(stringValue + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/AddKeyTransformFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AddKeyTransformFluentImpl<A extends AddKeyTransformFluent<A>> extends BaseFluent<A> implements AddKeyTransformFluent<A>{
  public AddKeyTransformFluentImpl() {
  }
  public AddKeyTransformFluentImpl(AddKeyTransform instance) {
    if (instance != null) {
      this.withJsonPathExpression(instance.getJsonPathExpression());
      this.withKey(instance.getKey());
      this.withStringValue(instance.getStringValue());
      this.withValue(instance.getValue());
    }
  }
  private String jsonPathExpression;
  private String key;
  private String stringValue;
  private String value;
  public String getJsonPathExpression() {
    return this.jsonPathExpression;
  }
  public A withJsonPathExpression(String jsonPathExpression) {
    this.jsonPathExpression=jsonPathExpression; return (A) this;
  }
  public Boolean hasJsonPathExpression() {
    return this.jsonPathExpression != null;
  }
  public String getKey() {
    return this.key;
  }
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  public Boolean hasKey() {
    return this.key != null;
  }
  public String getStringValue() {
    return this.stringValue;
  }
  public A withStringValue(String stringValue) {
    this.stringValue=stringValue; return (A) this;
  }
  public Boolean hasStringValue() {
    return this.stringValue != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddKeyTransformFluentImpl that = (AddKeyTransformFluentImpl) o;
    if (!java.util.Objects.equals(jsonPathExpression, that.jsonPathExpression)) return false;

    if (!java.util.Objects.equals(key, that.key)) return false;

    if (!java.util.Objects.equals(stringValue, that.stringValue)) return false;

    if (!java.util.Objects.equals(value, that.value)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(jsonPathExpression,  key,  stringValue,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (jsonPathExpression != null) { sb.append("jsonPathExpression:"); sb.append(jsonPathExpression + ","); }
    if (key != null) { sb.append("key:"); sb.append(key + ","); }
    if (stringValue != null) { sb.append("stringValue:"); sb.append(stringValue + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}
